<?php
/**
 * @file
 * Commerce Payserver Payment Admin Settings.
 */


/**
 * Returns the default settings for the Payserver payment method.
 */
function commerce_payserver_default_settings()
{
  return [
    'test' => [
      'private_key' => '',
      'public_key' => '',
    ],
    'live' => [
      'private_key' => '',
      'public_key' => '',
    ],
  ];
}

/**
 * Payment method callback: Generates the payment method settings form.
 */
function commerce_payserver_settings_form($settings = null) {
  $form = [];
  $settings = (array)$settings + [
      'public_key' => '',
      'private_key' => '',
      'live_link' => CONFIG['live_link'],
      'sandbox_link' => CONFIG['sandbox_link']
    ];
  $form['live_link'] = [
    '#type' => 'textfield',
    '#title' => t('Live link'),
    '#default_value' => $settings['live_link'],
    '#required' => true,
  ];
  $form['sandbox_link'] = [
    '#type' => 'textfield',
    '#title' => t('Sandbox link'),
    '#default_value' => $settings['sandbox_link'],
    '#required' => true,
  ];
  $form['public_key'] = [
    '#type' => 'textfield',
    '#title' => t('Merchant key'),
    '#default_value' => $settings['public_key'],
    '#required' => true,
  ];
  $form['private_key'] = [
    '#type' => 'textfield',
    '#title' => t('Merchant secret'),
    '#default_value' => $settings['private_key'],
    '#required' => true,
  ];
  $form['webhook_signing_key'] = [
    '#type' => 'textfield',
    '#title' => t('Webhook Signing Secret Key'),
    '#default_value' => $settings['webhook_signing_key'],
    '#required' => true,
  ];
  $form['mode'] = [
    '#type' => 'radios',
    '#title' => t('Mode'),
    '#options' => [
      'live' => t('Live'),
      'test' => t('Test'),
    ],
    '#default_value' => $settings['mode'],
    '#required' => true,
  ];
  $form['implementation'] = [
    '#type' => 'radios',
    '#title' => t('Implementation'),
    '#options' => [
      'light_api' => t('Light API'),
      'full' => t('Full integration'),
    ],
    '#default_value' => $settings['implementation'],
    '#required' => true,
  ];
  $form['ipn'] = ['#markup' =>  '<b>Webhooks Endpoint: </b>' . '<mark>' . t(commerce_payserver_ipn_url()) . '</mark>'];

  $form['#submit'][] = 'commerce_payserver_settings_submit_form';
  return $form;
}

/**
 * Payment method callback: submit form validation.
 */
function commerce_payserver_settings_submit_form($form, $form_state) {
  // Return an error if settings haven't been configured.
  if (empty($form['public_key']) || empty($form['private_key']) || empty($form['webhook_signing_key'])) {
    drupal_set_message(t(CONFIG['title'] . ' payment module is not configured for use. Please contact an administrator to resolve this issue.'), 'error');
    return FALSE;
  }

  return TRUE;
}

/**
 * Returns the IPN URL.
 *
 * @param null $instance_id
 * @return string
 */
function commerce_payserver_ipn_url($instance_id = null)
{
  $parts = array(
    'commerce_payserver',
    'ipn',
  );

  if (!empty($instance_id)) {
    $parts[] = $instance_id;
  }

  return url(implode('/', $parts), array('absolute' => true));
}
